/*
 ****************************************************************************
 *
 * Project configuration
 *
 ****************************************************************************
 */
#ifndef CONFIG_H
#define CONFIG_H

#include <pic14regs.h>



/*
 ****************************************************************************
 *
 * Software version
 *
 */
#define VER_MAJOR	1
#define VER_MINOR	1



/*
 ****************************************************************************
 *
 * CPU configuration
 *
 * Unfortunately, the address of the configuration word is not specified
 * in the chip include file...
 *
 */
#define CONFIG_VALUE	_INTRC_OSC_NOCLKOUT &				\
			_WDT_OFF & _PWRTE_ON & _MCLRE_ON &		\
			_BODEN_OFF & _CP_OFF & _CPD_OFF

#ifndef CONFIG_ADDR
# define CONFIG_ADDR	0x2007
#endif



/*
 ****************************************************************************
 *
 * Data EEPROM address
 *
 */
#ifndef EEPROM_ADDR
# define EEPROM_ADDR	0x2100
#endif



/*
 ****************************************************************************
 *
 * System clock frequency
 *
 */
#define SYS_CLOCK	4000000U



/*
 ****************************************************************************
 *
 * Frequency of the system timer tick, and values needed to program
 * timer 1 to generate the system timer tick
 *
 */
#define SYS_HZ			10
#define CYCLES_PER_HZ		(SYS_CLOCK / (4 * SYS_HZ))
#define TMR1_PRESCALE		1
#define TMR1_LATENCY		20
#define TMR1_RELOAD		(65535U - ((CYCLES_PER_HZ - TMR1_LATENCY) >> TMR1_PRESCALE) + 1)



/*
 ****************************************************************************
 *
 * Values for setting timer 0 to generate the serial port transmit/receive
 * clock
 *
 */
#define BAUDRATE		1200
#define DATA_BITS		8
#define STOP_BITS		1
#define IDLE_BITS		2
#define CYCLES_PER_BIT		(SYS_CLOCK / (4 * BAUDRATE))
#define CYCLES_PER_SBIT		(CYCLES_PER_BIT + (CYCLES_PER_BIT / 4))
#define TMR0_PRESCALE		2
#define TMR0_LATENCY		22
#define TMR0_RELOAD_BIT		(256 - ((CYCLES_PER_BIT - TMR0_LATENCY) >> TMR0_PRESCALE))
#define TMR0_RELOAD_SBIT	(256 - ((CYCLES_PER_SBIT - TMR0_LATENCY) >> TMR0_PRESCALE))



/*
 ****************************************************************************
 *
 * Various default timeout values
 *
 */


/* Timeout to switch system power on after power-on reset - 1000ms */
#define DEF_POR_TIMEOUT		(SYS_HZ * 1)


/* Timeout to toggle system power switch - 500ms */
#define DEF_POWER_TIMEOUT	(SYS_HZ / 2)


/* Timeout for power switch to turn off - 4000ms */
#define DEF_OFF_TIMEOUT		(SYS_HZ * 4)


/* Timeout for power switch to turn on - 500ms */
#define DEF_ON_TIMEOUT		(SYS_HZ / 2)


/* Timeout for power switch to activate interrupt - 500ms */
#define DEF_INT_TIMEOUT		(SYS_HZ / 2)


/* Watchdog timeout - 10000ms */
#define DEF_WD_TIMEOUT		(SYS_HZ * 10)


/* Timeout to restart the system after watchdog shutdown - 2000ms */
#define DEF_RESTART_TIMEOUT	(SYS_HZ * 2)


/* Maximum number of watchdog resets */
#define DEF_RESET_COUNT		4



/*
 ****************************************************************************
 *
 * Port definitions
 *
 */

/* TRIS value */
#define IO_TRIS		0x2E


/* Weak pullup value */
#define IO_WPU		0x24


/* Switch input (port pin and interrupt-on-change flag) */
#define SWITCH_PORT	GPIO5
#define SWITCH_IOC	IOC5


/* DTR input port (non-inverted comparator output, Vref = 1.9V and 3.1V) */
#define DTR_PORT	COUT
#define DTR_VR_LOW	0x85
#define DTR_VR_HIGH	0x8C
#define DTR_CMCON	0x04


/* RX input port (rising-edge triggered interrupt) */
#define RX_EDGE		0x40
#define RX_PORT		GPIO2
#define RX_IOC		IOC2
#define RX_IF		INTF
#define RX_IE		INTE


/* TX output port, note the inverted output levels for a direct connection */
#define TX_PORT		GPIO0
#define TX_HIGH		0
#define TX_LOW		1


/* Mainboard power output */
#define POWER_PORT	GPIO4



/*
 ****************************************************************************
 *
 * Some general definitions
 *
 */
#ifndef FALSE
# define FALSE	0
#endif

#ifndef TRUE
# define TRUE	1
#endif

#endif

